@@ -8,7 +8,7 @@ test_that("data frame variables converted to list names", {
   y <- ddply(esoph, .(alcgp, agegp), function(df) mean(df$ncases))
   labs <- paste(y$alcgp, y$agegp, sep = ".")
   expect_that(names(x), equals(labs))
-  
+
 })
 
 test_that("list names are preserved", {
@@ -17,5 +17,16 @@ test_that("list names are preserved", {
 
   names(a) <- letters[1:10]
   expect_that(names(llply(a)), equals(letters[1:10]))
+
+})
+
+# Test for #142
+test_that(".n column can be renamed", {
+  f <- function() data.frame(r=runif(1))
   
-})
\ No newline at end of file
+  out1 <- rdply(4, f)
+  out2 <- rdply(4, f, .id='x')
+  
+  expect_equal(names(out1), c('.n', 'r'))
+  expect_equal(names(out2), c('x', 'r'))
+})
