@@ -55,7 +55,22 @@ test_that("NAs are placed last", {
   expect_that(id_var(c(NA, 1)), is_equivalent_to(c(2, 1)))
 })
 
-test_that("zero length input gives single number", {
-  expect_that(id(character()), is_equivalent_to(1))  
+test_that("factor with missing levels has correct count", {
+  id <- id_var(factor(1, NA))
+  expect_equal(attr(id, "n"), 1)
 })
 
+test_that("zero length input gives single number", {
+  expect_that(id(character()), is_equivalent_to(integer()))
+})
+
+test_that("zero column data frame gives seq_len(nrow)", {
+  df <- as.data.frame(matrix(nrow = 10, ncol = 0))
+  expect_equivalent(id(df), 1:10)
+})
+
+test_that("empty list doesn't affect n", {
+  out <- id(list(integer(), 1:5))
+  expect_equivalent(out, 1:5)
+  expect_equal(attr(out, "n"), 5)
+})
