@@ -103,20 +103,55 @@ test_that("names preserved and filled for atomic vectors", {
 })
 
 test_that("names captured from list", {
-  li <- list(a = 1:5, b = 5:10, c = 5:15)
+  li <- list(c = 5:15, b = 5:10, a = 1:5)
 
   df <- ldply(li, function(x) mean(x))
-  expect_that(df$.id, equals(c("a", "b", "c")))
+  expect_that(df$.id, equals(names(li)))
 
   df <- ldply(li, function(x) {
       if (any(x >= 10)) mean(x)
   })
-  expect_that(df$.id, equals(c("b", "c")))
+  expect_that(df$.id, equals(names(li)[-3]))
 })
 
 test_that("correct number of rows outputted", {
   testdata <- data.frame(a = rep(letters[1:3], each = 5), b = rnorm(15))
   res <- ddply(testdata, .(a), function(x) c(mean(x$b), sd(x$b)))
-  
+
   expect_that(nrow(res), equals(3))
 })
+
+test_that("matrices converted to data frames, without id column", {
+  mat <- matrix(1:20, ncol = 4)
+  colnames(mat) <- letters[1:4]
+
+  li <- list(a = mat, b = mat)
+  df <- list_to_dataframe(li)
+
+  expect_equal(nrow(df), 2 * nrow(mat))
+  expect_equal(names(df), c("a", "b", "c", "d"))
+})
+
+test_that("matrices converted to data frames, with id column", {
+  mat <- matrix(1:20, ncol = 4)
+  colnames(mat) <- letters[1:4]
+  
+  li <- list(a = mat, b = mat)
+  df <- plyr:::list_to_dataframe(li, id_name = "my_id")
+  
+  expect_equal(nrow(df), 2 * nrow(mat))
+  expect_equal(names(df), c("my_id", "a", "b", "c", "d"))
+  expect_equal(df$my_id, rep(c("a", "b"), c(5, 5)))
+})
+
+test_that("matrices converted to data frames, with id column as factor", {
+  mat <- matrix(1:20, ncol = 4)
+  colnames(mat) <- letters[1:4]
+  
+  li <- list(a = mat, b = mat)
+  df <- list_to_dataframe(li, id_name = "my_id", id_as_factor = TRUE)
+  
+  expect_equal(nrow(df), 2 * nrow(mat))
+  expect_equal(names(df), c("my_id", "a", "b", "c", "d"))
+  expect_equal(levels(df$my_id), c("a", "b"))
+})
